"use client";

import { useState } from "react";
import { XMarkIcon } from "@heroicons/react/24/outline";
import { addTransaction } from "@/lib/db";

interface TransactionFormProps {
  isOpen: boolean;
  type: "INCOME" | "EXPENSE";
  onClose: () => void;
  onTransactionAdded: () => void;
}

interface FormData {
  amount: string;
  category: string;
  title: string;
  date: string;
  isRecurring: boolean;
  recurringPeriod: "weekly" | "monthly" | "yearly" | undefined;
}

export default function TransactionForm({
  type,
  onClose,
  onTransactionAdded,
}: TransactionFormProps) {
  const [formData, setFormData] = useState<FormData>({
    amount: "",
    category: "",
    title: "",
    date: new Date().toISOString().split("T")[0],
    isRecurring: false,
    recurringPeriod: undefined,
  });

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();
    try {
      const newTransaction = {
        amount: Number(formData.amount),
        type,
        category: formData.category,
        title: formData.title,
        date: new Date(formData.date),
        isRecurring: formData.isRecurring,
        recurringPeriod: formData.isRecurring
          ? formData.recurringPeriod
          : undefined,
      };
      await addTransaction(newTransaction);
      onTransactionAdded();
      onClose();
    } catch (error) {
      console.error("Error al agregar transacción:", error);
    }
  };

  return (
    <div className="fixed inset-0 bg-black bg-opacity-50 flex items-center justify-center p-4 z-50">
      <div className="bg-gray-800 rounded-lg max-w-md max-h-[90vh] overflow-y-auto relative">
        <div className="p-6">
          <button
            onClick={onClose}
            className="absolute top-4 right-4 text-gray-400 hover:text-white"
          >
            <XMarkIcon className="h-6 w-6" />
          </button>
          <h2 className="text-xl font-semibold mb-6">
            {type === "INCOME" ? "Nuevo Ingreso" : "Nuevo Gasto"}
          </h2>
          <form onSubmit={handleSubmit} className="space-y-4">
            <div>
              <label className="block text-sm font-medium text-gray-300 mb-1">
                Título
              </label>
              <input
                type="text"
                value={formData.title}
                onChange={(e) =>
                  setFormData({ ...formData, title: e.target.value })
                }
                className="w-full px-3 py-2 bg-gray-700 border border-gray-600 rounded-md text-white focus:outline-none focus:ring-2 focus:ring-blue-500"
                required
              />
            </div>
            <div>
              <label className="block text-sm font-medium text-gray-300 mb-1">
                Monto
              </label>
              <input
                type="number"
                value={formData.amount}
                onChange={(e) =>
                  setFormData({ ...formData, amount: e.target.value })
                }
                className="w-full px-3 py-2 bg-gray-700 border border-gray-600 rounded-md text-white focus:outline-none focus:ring-2 focus:ring-blue-500"
                required
                min="0"
                step="0.01"
              />
            </div>
            <div>
              <label className="block text-sm font-medium text-gray-300 mb-1">
                Categoría
              </label>
              <select
                value={formData.category}
                onChange={(e) =>
                  setFormData({ ...formData, category: e.target.value })
                }
                className="w-full px-3 py-2 bg-gray-700 border border-gray-600 rounded-md text-white focus:outline-none focus:ring-2 focus:ring-blue-500"
                required
              >
                <option value="">Selecciona una categoría</option>
                {type === "INCOME" ? (
                  <>
                    <option value="Salario">Salario</option>
                    <option value="Freelance">Freelance</option>
                    <option value="Inversiones">Inversiones</option>
                    <option value="Otros">Otros</option>
                  </>
                ) : (
                  <>
                    <option value="Alquiler">Alquiler</option>
                    <option value="Servicios">Servicios</option>
                    <option value="Compras">Compras</option>
                    <option value="Transporte">Transporte</option>
                    <option value="Entretenimiento">Entretenimiento</option>
                    <option value="Otros">Otros</option>
                  </>
                )}
              </select>
            </div>
            <div>
              <label className="block text-sm font-medium text-gray-300 mb-1">
                Fecha
              </label>
              <input
                type="date"
                value={formData.date}
                onChange={(e) =>
                  setFormData({ ...formData, date: e.target.value })
                }
                className="w-full px-3 py-2 bg-gray-700 border border-gray-600 rounded-md text-white focus:outline-none focus:ring-2 focus:ring-blue-500"
                required
              />
            </div>
            <div className="flex items-center space-x-2">
              <input
                type="checkbox"
                id="recurring"
                checked={formData.isRecurring}
                onChange={(e) =>
                  setFormData({ ...formData, isRecurring: e.target.checked })
                }
                className="h-4 w-4 text-blue-500 focus:ring-blue-500 border-gray-600 rounded bg-gray-700"
              />
              <label
                htmlFor="recurring"
                className="text-sm font-medium text-gray-300"
              >
                Recurrente
              </label>
            </div>
            {formData.isRecurring && (
              <div>
                <label className="block text-sm font-medium text-gray-300 mb-1">
                  Periodicidad
                </label>
                <select
                  value={formData.recurringPeriod}
                  onChange={(e) =>
                    setFormData({
                      ...formData,
                      recurringPeriod: e.target.value as
                        | "weekly"
                        | "monthly"
                        | "yearly"
                        | undefined,
                    })
                  }
                  className="w-full px-3 py-2 bg-gray-700 border border-gray-600 rounded-md text-white focus:outline-none focus:ring-2 focus:ring-blue-500"
                  required
                >
                  <option value="weekly">Semanal</option>
                  <option value="monthly">Mensual</option>
                  <option value="yearly">Anual</option>
                </select>
              </div>
            )}
            <div className="flex justify-end space-x-3 mt-6">
              <button
                type="button"
                onClick={onClose}
                className="px-4 py-2 text-sm font-medium text-gray-300 hover:text-white"
              >
                Cancelar
              </button>
              <button
                type="submit"
                className="px-4 py-2 text-sm font-medium text-white bg-blue-600 rounded-md hover:bg-blue-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500"
              >
                Guardar
              </button>
            </div>
          </form>
        </div>
      </div>
    </div>
  );
}
